<template>
  <div
    element-loading-text="数据加载中..."
    element-loading-spinner="el-icon-loading"
    element-loading-background="rgba(255,255,255, 0.5)"
    v-loading.fullscreen.lock="loading"
  >
    <el-dialog
      v-dialogDrag
      :title="type + '噪音分类'"
      :visible="visible"
      :before-close="handleClose"
      :close-on-click-modal="false"
      v-if="visible"
      width="50%"
      top="6vh"
      :class="[loading ? 'dialog-box' : '']"
    >
      <div>
        <el-form ref="form" :rules="rules" :model="formData" label-width="80px">
          <el-row>
            <el-col :span="12">
              <el-form-item label="分类名称" prop="name">
                <el-input
                  style="width: 100%"
                  clearable
                  v-model="formData.name"
                  placeholder="请输入分类名称"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="噪音编码" prop="code">
                <el-input
                  clearable
                  style="width: 100%"
                  v-model="formData.code"
                  placeholder="请输入噪音编码"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="24">
              <el-form-item label="适用区域" prop="postalCode">
                <el-input
                  type="textarea"
                  rows="4"
                  style="width: 100%"
                  v-model="formData.postalCode"
                  placeholder="请输入适用区域"
                >
                </el-input>
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <div
        slot="footer"
        class="dialog-footer"
        :style="loading ? 'position: relative;z-index: -1;' : ''"
      >
        <el-button @click="handleClose">取消</el-button>
        <el-button type="primary" @click="handleSave" :loading="btnLoading">确认</el-button>
      </div>
    </el-dialog>
  </div>
</template>
        
<script>
import utils from '@/utils.js'
import NoiseClassify from '@/api/basicConfiguration/NoiseClassify'

export default {
  props: {},
  name: 'NoiseClassifyDialog',
  data() {
    return {
      visible: false,
      loading: false,
      type: '新增',
      rules: {
        name: [
          {
            required: true,
            message: '请输入分类名称',
            trigger: 'blur',
          },
        ],
        code: [
          {
            required: true,
            message: '请输入分类编码',
            trigger: 'blur',
          },
        ],
        postalCode: [
          {
            required: true,
            message: '适用区域',
            trigger: 'blur',
          },
        ],
      },
      formData: {},
      btnLoading:false
    }
  },
  methods: {
    open(data) {
      this.formData = {}
      this.visible = true
      this.type = '新增'
    },
    handleClose() {
      this.visible = false
    },
    //编辑
    edit(id) {
      this.formData = {}
      this.visible = true
      this.type = '编辑'
      NoiseClassify.detailId(id, (res) => {
        this.formData = res
      })
    },
    //保存
    handleSave() {
      this.$refs.form.validate((valid) => {
        if (valid) {
          this.btnLoading=true
          // this.params.productId = this.params.productId.pop()
          // let tempData = utils.deepClone(this.params)
          // tempData = this.handleExtendSave(tempData)
          let method
          if (this.type === '新增') {
            method = NoiseClassify.addSave
          } else {
            method = NoiseClassify.upData
          }
          method(this.formData, (response) => {
            if (response.state) {
              this.$notify({
                type: 'success',
                message: this.type + '成功',
                duration: 2000,
              })
              this.handleClose()
              this.$emit('getData')
            } else {
              this.$message.warning(response.message)
            }
          this.btnLoading=false
          })
        } else {
          this.$notify({
            type: 'warning',
            message: '请完善表单信息！',
            duration: 2000,
          })
        }
      })
    },
  },
}
</script>

<style lang="scss" scoped>
/deep/.el-dialog__wrapper {
  overflow: hidden;
}

.dialog-footer {
  display: flex;
  justify-content: flex-end;
}

//加载遮罩
/deep/.el-dialog__body {
  box-sizing: border-box;

  .el-loading-parent--relative {
    max-height: inherit;
  }
}
</style>